@@ -1,7 +1,7 @@
 RGEOSUnaryPredFunc = function(spgeom, byid, func) {
     byid = as.logical(byid)
     if (is.na(byid)) stop("Invalid value for byid, must be logical")
-    if (inherits(spgeom, "SpatialPolygons")) 
+    if (inherits(spgeom, "SpatialPolygons") && get_do_poly_check()) 
         spgeom <- createSPComment(spgeom)
 
     x <- .Call(func, .RGEOS_HANDLE, spgeom, byid, PACKAGE="rgeos")
